@@ -17,6 +17,9 @@ func readLine(reader io.Reader, cb func(ret []byte)) ([]byte, error) {
 		n, err := reader.Read(buf[:])
 		if n > 0 {
 			switch buf[0] {
+			case '':
+				// ignore ESC sequences
+				continue
 			case '', '\b':
 				if len(ret) > 0 {
 					ret = ret[:len(ret)-1]
